@@ -1,6 +1,7 @@
 from .api_client import NutanixApiClient, NutanixSession
 from .nutanix_cluster import ClusterMetadata, ClusterSpec, ClusterStatus, NutanixCluster
 from .nutanix_vm import NutanixVM, PowerState, VMMetadata, VMSpec, VMStatus
+from .nutanix_image import NutanixImage, ImageSpec, ImageStatus, ImageMetadata
 
 __all__ = [
     "PowerState",
@@ -8,10 +9,14 @@ __all__ = [
     "NutanixCluster",
     "NutanixApiClient",
     "NutanixSession",
+    "NutanixImage",
     "PowerState",
     "VMMetadata",
     "VMStatus",
     "VMSpec",
+    "ImageMetadata",
+    "ImageStatus",
+    "ImageSpec",
     "ClusterMetadata",
     "ClusterStatus",
     "ClusterSpec",
